@@ -1,6 +1,6 @@
 pub use crate::array::default_arrays::*;
-pub use crate::array::*;
 pub use crate::kernels::rolling::no_nulls::QuantileInterpolOptions;
+pub use crate::{array::*, index::*};
 use arrow::array::{ListArray, Utf8Array};
 
 pub type LargeStringArray = Utf8Array<i64>;
