@@ -1,5 +1,6 @@
 use crate::prelude::*;
 
+use polars_arrow::prelude::FromData;
 #[cfg(feature = "random")]
 use rand::prelude::SliceRandom;
 #[cfg(feature = "random")]
@@ -37,13 +38,13 @@ pub(crate) fn rank(s: &Series, method: RankMethod, reverse: bool) -> Series {
         1 => {
             return match method {
                 Average => Series::new(s.name(), &[1.0f32]),
-                _ => Series::new(s.name(), &[1u32]),
+                _ => Series::new(s.name(), &[1 as IdxSize]),
             };
         }
         0 => {
             return match method {
                 Average => Float32Chunked::from_slice(s.name(), &[]).into_series(),
-                _ => UInt32Chunked::from_slice(s.name(), &[]).into_series(),
+                _ => IdxCa::from_slice(s.name(), &[]).into_series(),
             };
         }
         _ => {}
@@ -69,7 +70,7 @@ pub(crate) fn rank(s: &Series, method: RankMethod, reverse: bool) -> Series {
     let sort_idx_ca = s.argsort(reverse);
     let sort_idx = sort_idx_ca.downcast_iter().next().unwrap().values();
 
-    let mut inv: Vec<u32> = Vec::with_capacity(len);
+    let mut inv: Vec<IdxSize> = Vec::with_capacity(len);
     // Safety:
     // Values will be filled next and there is only primitive data
     #[allow(clippy::uninit_vec)]
@@ -80,14 +81,14 @@ pub(crate) fn rank(s: &Series, method: RankMethod, reverse: bool) -> Series {
 
     #[cfg(feature = "random")]
     let mut count = if let RankMethod::Ordinal | RankMethod::Random = method {
-        1u32
+        1 as IdxSize
     } else {
         0
     };
 
     #[cfg(not(feature = "random"))]
     let mut count = if let RankMethod::Ordinal = method {
-        1u32
+        1 as IdxSize
     } else {
         0
     };
@@ -104,7 +105,7 @@ pub(crate) fn rank(s: &Series, method: RankMethod, reverse: bool) -> Series {
     use RankMethod::*;
     match method {
         Ordinal => {
-            let inv_ca = UInt32Chunked::from_vec(s.name(), inv);
+            let inv_ca = IdxCa::from_vec(s.name(), inv);
             inv_ca.into_series()
         }
         #[cfg(feature = "random")]
@@ -147,7 +148,7 @@ pub(crate) fn rank(s: &Series, method: RankMethod, reverse: bool) -> Series {
             }
 
             // Recreate inv_ca (where ties are randomly shuffled compared with Ordinal).
-            let mut count = 1u32;
+            let mut count = 1 as IdxSize;
             unsafe {
                 sort_idx.iter().for_each(|&i| {
                     *inv_values.get_unchecked_mut(i as usize) = count;
@@ -155,11 +156,11 @@ pub(crate) fn rank(s: &Series, method: RankMethod, reverse: bool) -> Series {
                 });
             }
 
-            let inv_ca = UInt32Chunked::from_vec(s.name(), inv);
+            let inv_ca = IdxCa::from_vec(s.name(), inv);
             inv_ca.into_series()
         }
         _ => {
-            let inv_ca = UInt32Chunked::from_vec(s.name(), inv);
+            let inv_ca = IdxCa::from_vec(s.name(), inv);
             // Safety:
             // in bounds
             let arr = unsafe { s.take_unchecked(&sort_idx_ca).unwrap() };
@@ -178,7 +179,7 @@ pub(crate) fn rank(s: &Series, method: RankMethod, reverse: bool) -> Series {
             //     if method == 'min':
             //         return count[dense - 1] + 1
             // ```
-            let mut cumsum: u32 = if let RankMethod::Min = method { 0 } else { 1 };
+            let mut cumsum: IdxSize = if let RankMethod::Min = method { 0 } else { 1 };
 
             dense.push(cumsum);
             obs.values_iter().for_each(|b| {
@@ -187,9 +188,8 @@ pub(crate) fn rank(s: &Series, method: RankMethod, reverse: bool) -> Series {
                 }
                 dense.push(cumsum)
             });
-            let arr =
-                PrimitiveArray::from_data(DataType::UInt32.to_arrow(), dense.into(), validity);
-            let dense: UInt32Chunked = (s.name(), arr).into();
+            let arr = IdxArr::from_data_default(dense.into(), validity);
+            let dense: IdxCa = (s.name(), arr).into();
             // Safety:
             // in bounds
             let dense = unsafe { dense.take_unchecked((&inv_ca).into()) };
@@ -201,7 +201,7 @@ pub(crate) fn rank(s: &Series, method: RankMethod, reverse: bool) -> Series {
             let bitmap = obs.values();
             let cap = bitmap.len() - bitmap.null_count();
             let mut count = Vec::with_capacity(cap + 1);
-            let mut cnt = 0u32;
+            let mut cnt: IdxSize = 0;
             count.push(cnt);
 
             if null_count > 0 {
@@ -222,8 +222,8 @@ pub(crate) fn rank(s: &Series, method: RankMethod, reverse: bool) -> Series {
                 });
             }
 
-            count.push((len - null_count) as u32);
-            let count = UInt32Chunked::from_vec(s.name(), count);
+            count.push((len - null_count) as IdxSize);
+            let count = IdxCa::from_vec(s.name(), count);
 
             match method {
                 Max => {
@@ -266,15 +266,15 @@ mod test {
         let s = Series::new("a", &[1, 2, 3, 2, 2, 3, 0]);
 
         let out = rank(&s, RankMethod::Ordinal, false)
-            .u32()?
+            .idx()?
             .into_no_null_iter()
             .collect::<Vec<_>>();
-        assert_eq!(out, &[2, 3, 6, 4, 5, 7, 1]);
+        assert_eq!(out, &[2 as IdxSize, 3, 6, 4, 5, 7, 1]);
 
         #[cfg(feature = "random")]
         {
             let out = rank(&s, RankMethod::Random, false)
-                .u32()?
+                .idx()?
                 .into_no_null_iter()
                 .collect::<Vec<_>>();
             assert_eq!(out[0], 2);
@@ -287,19 +287,19 @@ mod test {
         }
 
         let out = rank(&s, RankMethod::Dense, false)
-            .u32()?
+            .idx()?
             .into_no_null_iter()
             .collect::<Vec<_>>();
         assert_eq!(out, &[2, 3, 4, 3, 3, 4, 1]);
 
         let out = rank(&s, RankMethod::Max, false)
-            .u32()?
+            .idx()?
             .into_no_null_iter()
             .collect::<Vec<_>>();
         assert_eq!(out, &[2, 5, 7, 5, 5, 7, 1]);
 
         let out = rank(&s, RankMethod::Min, false)
-            .u32()?
+            .idx()?
             .into_no_null_iter()
             .collect::<Vec<_>>();
         assert_eq!(out, &[2, 3, 6, 3, 3, 6, 1]);
@@ -346,7 +346,7 @@ mod test {
             ],
         );
         let out = rank(&s, RankMethod::Max, false)
-            .u32()?
+            .idx()?
             .into_no_null_iter()
             .collect::<Vec<_>>();
         assert_eq!(out, &[5, 6, 4, 1, 8, 4, 2, 7]);
@@ -363,7 +363,7 @@ mod test {
             .collect::<Vec<_>>();
         assert_eq!(out, &[2.0f32, 2.0, 2.0]);
         let out = rank(&s, RankMethod::Dense, false)
-            .u32()?
+            .idx()?
             .into_no_null_iter()
             .collect::<Vec<_>>();
         assert_eq!(out, &[1, 1, 1]);
@@ -376,17 +376,17 @@ mod test {
         let out = rank(&s, RankMethod::Average, false);
         assert_eq!(out.dtype(), &DataType::Float32);
         let out = rank(&s, RankMethod::Max, false);
-        assert_eq!(out.dtype(), &DataType::UInt32);
+        assert_eq!(out.dtype(), &IDX_DTYPE);
     }
 
     #[test]
     fn test_rank_reverse() -> Result<()> {
         let s = Series::new("", &[None, Some(1), Some(1), Some(5), None]);
         let out = rank(&s, RankMethod::Dense, true)
-            .u32()?
+            .idx()?
             .into_no_null_iter()
             .collect::<Vec<_>>();
-        assert_eq!(out, &[1, 3, 3, 2, 1]);
+        assert_eq!(out, &[1 as IdxSize, 3, 3, 2, 1]);
 
         Ok(())
     }
