@@ -58,7 +58,7 @@ where
                 .collect::<PrimitiveArray<T::Native>>()
                 .to(T::get_dtype().to_arrow()),
         };
-        ChunkedArray::new_from_chunks("", vec![Arc::new(arr)])
+        ChunkedArray::from_chunks("", vec![Arc::new(arr)])
     }
 }
 
@@ -79,7 +79,7 @@ where
 impl FromIterator<Option<bool>> for ChunkedArray<BooleanType> {
     fn from_iter<I: IntoIterator<Item = Option<bool>>>(iter: I) -> Self {
         let arr = BooleanArray::from_iter(iter);
-        Self::new_from_chunks("", vec![Arc::new(arr)])
+        Self::from_chunks("", vec![Arc::new(arr)])
     }
 }
 
@@ -87,7 +87,7 @@ impl FromIterator<bool> for BooleanChunked {
     fn from_iter<I: IntoIterator<Item = bool>>(iter: I) -> Self {
         // 2021-02-07: this was ~70% faster than with the builder, even with the extra Option<T> added.
         let arr = BooleanArray::from_iter(iter.into_iter().map(Some));
-        Self::new_from_chunks("", vec![Arc::new(arr)])
+        Self::from_chunks("", vec![Arc::new(arr)])
     }
 }
 
@@ -106,7 +106,7 @@ where
 {
     fn from_iter<I: IntoIterator<Item = Option<Ptr>>>(iter: I) -> Self {
         let arr = Utf8Array::<i64>::from_iter(iter);
-        Self::new_from_chunks("", vec![Arc::new(arr)])
+        Self::from_chunks("", vec![Arc::new(arr)])
     }
 }
 
@@ -125,7 +125,7 @@ where
 {
     fn from_iter<I: IntoIterator<Item = Ptr>>(iter: I) -> Self {
         let arr = Utf8Array::<i64>::from_iter_values(iter.into_iter());
-        Self::new_from_chunks("", vec![Arc::new(arr)])
+        Self::from_chunks("", vec![Arc::new(arr)])
     }
 }
 
@@ -395,7 +395,7 @@ where
             av.extend_from_slice(&v)
         }
         let arr = to_array::<T>(av, None);
-        NoNull::new(ChunkedArray::new_from_chunks("", vec![arr]))
+        NoNull::new(ChunkedArray::from_chunks("", vec![arr]))
     }
 }
 
@@ -412,7 +412,7 @@ where
         let iter = TrustMyLength::new(vectors.into_iter().flatten(), capacity);
         let arr =
             PrimitiveArray::<T::Native>::from_trusted_len_iter(iter).to(T::get_dtype().to_arrow());
-        Self::new_from_chunks("", vec![Arc::new(arr)])
+        Self::from_chunks("", vec![Arc::new(arr)])
     }
 }
 
@@ -427,7 +427,7 @@ impl FromParallelIterator<bool> for BooleanChunked {
                 vectors.into_iter().flatten().trust_my_length(capacity),
             )
         };
-        Self::new_from_chunks("", vec![Arc::new(arr)])
+        Self::from_chunks("", vec![Arc::new(arr)])
     }
 }
 
@@ -438,7 +438,7 @@ where
     fn from_par_iter<I: IntoParallelIterator<Item = Ptr>>(iter: I) -> Self {
         let vectors = collect_into_linked_list(iter);
         let arr = LargeStringArray::from_iter_values(vectors.into_iter().flatten());
-        Self::new_from_chunks("", vec![Arc::new(arr)])
+        Self::from_chunks("", vec![Arc::new(arr)])
     }
 }
 
@@ -449,7 +449,7 @@ where
     fn from_par_iter<I: IntoParallelIterator<Item = Option<Ptr>>>(iter: I) -> Self {
         let vectors = collect_into_linked_list(iter);
         let arr = LargeStringArray::from_iter(vectors.into_iter().flatten());
-        Self::new_from_chunks("", vec![Arc::new(arr)])
+        Self::from_chunks("", vec![Arc::new(arr)])
     }
 }
 
