@@ -59,7 +59,7 @@ macro_rules! impl_dyn_series {
             }
 
             #[cfg(feature = "asof_join")]
-            fn join_asof(&self, other: &Series) -> Result<Vec<Option<u32>>> {
+            fn join_asof(&self, other: &Series) -> Result<Vec<Option<IdxSize>>> {
                 let other = other.to_physical_repr();
                 self.0.deref().join_asof(&other)
             }
@@ -150,22 +150,22 @@ macro_rules! impl_dyn_series {
                     .map(|s| s.$into_logical().into_series())
             }
 
-            fn hash_join_inner(&self, other: &Series) -> Vec<(u32, u32)> {
+            fn hash_join_inner(&self, other: &Series) -> Vec<(IdxSize, IdxSize)> {
                 let other = other.to_physical_repr().into_owned();
                 self.0.hash_join_inner(&other.as_ref().as_ref())
             }
-            fn hash_join_left(&self, other: &Series) -> Vec<(u32, Option<u32>)> {
+            fn hash_join_left(&self, other: &Series) -> Vec<(IdxSize, Option<IdxSize>)> {
                 let other = other.to_physical_repr().into_owned();
                 self.0.hash_join_left(&other.as_ref().as_ref())
             }
-            fn hash_join_outer(&self, other: &Series) -> Vec<(Option<u32>, Option<u32>)> {
+            fn hash_join_outer(&self, other: &Series) -> Vec<(Option<IdxSize>, Option<IdxSize>)> {
                 let other = other.to_physical_repr().into_owned();
                 self.0.hash_join_outer(&other.as_ref().as_ref())
             }
             fn zip_outer_join_column(
                 &self,
                 right_column: &Series,
-                opt_join_tuples: &[(Option<u32>, Option<u32>)],
+                opt_join_tuples: &[(Option<IdxSize>, Option<IdxSize>)],
             ) -> Series {
                 let right_column = right_column.to_physical_repr().into_owned();
                 self.0
@@ -221,7 +221,7 @@ macro_rules! impl_dyn_series {
                 self.0.group_tuples(multithreaded, sorted)
             }
             #[cfg(feature = "sort_multiple")]
-            fn argsort_multiple(&self, by: &[Series], reverse: &[bool]) -> Result<UInt32Chunked> {
+            fn argsort_multiple(&self, by: &[Series], reverse: &[bool]) -> Result<IdxCa> {
                 self.0.deref().argsort_multiple(by, reverse)
             }
         }
@@ -346,7 +346,7 @@ macro_rules! impl_dyn_series {
                     .map(|ca| ca.$into_logical().into_series())
             }
 
-            fn take(&self, indices: &UInt32Chunked) -> Result<Series> {
+            fn take(&self, indices: &IdxCa) -> Result<Series> {
                 ChunkTake::take(self.0.deref(), indices.into())
                     .map(|ca| ca.$into_logical().into_series())
             }
@@ -366,7 +366,7 @@ macro_rules! impl_dyn_series {
                     .into_series()
             }
 
-            unsafe fn take_unchecked(&self, idx: &UInt32Chunked) -> Result<Series> {
+            unsafe fn take_unchecked(&self, idx: &IdxCa) -> Result<Series> {
                 Ok(ChunkTake::take_unchecked(self.0.deref(), idx.into())
                     .$into_logical()
                     .into_series())
@@ -424,7 +424,7 @@ macro_rules! impl_dyn_series {
                 self.0.sort_with(options).$into_logical().into_series()
             }
 
-            fn argsort(&self, reverse: bool) -> UInt32Chunked {
+            fn argsort(&self, reverse: bool) -> IdxCa {
                 self.0.argsort(reverse)
             }
 
@@ -444,7 +444,7 @@ macro_rules! impl_dyn_series {
                 self.0.n_unique()
             }
 
-            fn arg_unique(&self) -> Result<UInt32Chunked> {
+            fn arg_unique(&self) -> Result<IdxCa> {
                 self.0.arg_unique()
             }
 
@@ -557,7 +557,7 @@ macro_rules! impl_dyn_series {
                 self.0.is_in(other)
             }
             #[cfg(feature = "repeat_by")]
-            fn repeat_by(&self, by: &UInt32Chunked) -> ListChunked {
+            fn repeat_by(&self, by: &IdxCa) -> ListChunked {
                 match self.0.dtype() {
                     DataType::Date => self
                         .0
