@@ -360,11 +360,7 @@ impl Series {
     ///
     /// # Safety
     /// This doesn't check any bounds. Null validity is checked.
-    pub unsafe fn take_unchecked_threaded(
-        &self,
-        idx: &UInt32Chunked,
-        rechunk: bool,
-    ) -> Result<Series> {
+    pub unsafe fn take_unchecked_threaded(&self, idx: &IdxCa, rechunk: bool) -> Result<Series> {
         let n_threads = POOL.current_num_threads();
         let idx = split_ca(idx, n_threads)?;
 
@@ -390,7 +386,7 @@ impl Series {
     /// # Safety
     ///
     /// Out of bounds access doesn't Error but will return a Null value
-    pub fn take_threaded(&self, idx: &UInt32Chunked, rechunk: bool) -> Result<Series> {
+    pub fn take_threaded(&self, idx: &IdxCa, rechunk: bool) -> Result<Series> {
         let n_threads = POOL.current_num_threads();
         let idx = split_ca(idx, n_threads).unwrap();
 
@@ -948,6 +944,26 @@ impl Series {
             s
         }
     }
+
+    /// Compute the unique elements, but maintain order. This requires more work
+    /// than a naive [`Series::unique`].
+    pub fn unique_stable(&self) -> Result<Series> {
+        let idx = self.arg_unique()?;
+        // Safety:
+        // Indices are in bounds.
+        unsafe { self.take_unchecked(&idx) }
+    }
+
+    pub fn idx(&self) -> Result<&IdxCa> {
+        #[cfg(feature = "bigidx")]
+        {
+            self.u64()
+        }
+        #[cfg(not(feature = "bigidx"))]
+        {
+            self.u32()
+        }
+    }
 }
 
 impl Deref for Series {
