@@ -8,6 +8,8 @@ pub mod moment;
 mod null;
 #[cfg(feature = "pct_change")]
 pub mod pct_change;
+#[cfg(feature = "round_series")]
+mod round;
 mod to_list;
 
 #[derive(Copy, Clone)]
