@@ -11,6 +11,9 @@ use rayon::prelude::*;
 use std::borrow::Cow;
 use std::ops::{Deref, DerefMut};
 
+#[cfg(feature = "private")]
+pub use crate::chunked_array::ops::sort::argsort_no_nulls;
+
 #[repr(transparent)]
 pub struct Wrap<T>(pub T);
 
@@ -357,11 +360,12 @@ macro_rules! df {
 }
 
 #[cfg(feature = "private")]
-pub fn get_time_units(l: &TimeUnit, r: &TimeUnit) -> TimeUnit {
-    if l == r {
-        *l
-    } else {
-        TimeUnit::Milliseconds
+pub fn get_time_units(tu_l: &TimeUnit, tu_r: &TimeUnit) -> TimeUnit {
+    use TimeUnit::*;
+    match (tu_l, tu_r) {
+        (Nanoseconds, Microseconds) => Microseconds,
+        (_, Milliseconds) => Milliseconds,
+        _ => *tu_l,
     }
 }
 
@@ -611,45 +615,34 @@ fn _get_supertype(l: &DataType, r: &DataType) -> Option<DataType> {
         }
         (Duration(_), Date) | (Date, Duration(_)) => Some(Datetime(TimeUnit::Milliseconds, None)),
         (Duration(lu), Duration(ru)) => Some(Duration(get_time_units(lu, ru))),
-        // we cast nanoseconds to milliseconds as that always fits with occasional loss of precision
-        (Datetime(TimeUnit::Nanoseconds, None), Datetime(TimeUnit::Milliseconds, None))
-        | (Datetime(TimeUnit::Milliseconds, None), Datetime(TimeUnit::Nanoseconds, None)) => {
-            Some(Datetime(TimeUnit::Milliseconds, None))
-        }
+
         // None and Some("") timezones
-        (Datetime(TimeUnit::Nanoseconds, None), Datetime(TimeUnit::Nanoseconds, tz))
-            if tz.as_deref() == Some("") =>
+        // we cast from more precision to higher precision as that always fits with occasional loss of precision
+        (Datetime(tu_l, tz_l), Datetime(tu_r, tz_r))
+            if (tz_l.is_none() || tz_l.as_deref() == Some(""))
+                && (tz_r.is_none() || tz_r.as_deref() == Some("")) =>
         {
-            Some(Datetime(TimeUnit::Nanoseconds, None))
+            let tu = get_time_units(tu_l, tu_r);
+            Some(Datetime(tu, None))
         }
-        (Datetime(TimeUnit::Nanoseconds, tz), Datetime(TimeUnit::Nanoseconds, None))
-            if tz.as_deref() == Some("") =>
-        {
-            Some(Datetime(TimeUnit::Nanoseconds, None))
-        }
-        (Datetime(TimeUnit::Milliseconds, None), Datetime(TimeUnit::Milliseconds, tz))
-            if tz.as_deref() == Some("") =>
-        {
-            Some(Datetime(TimeUnit::Milliseconds, None))
-        }
-        (Datetime(TimeUnit::Milliseconds, tz), Datetime(TimeUnit::Milliseconds, None))
-            if tz.as_deref() == Some("") =>
-        {
-            Some(Datetime(TimeUnit::Milliseconds, None))
-        }
-
-        (Datetime(TimeUnit::Nanoseconds, tz_l), Datetime(TimeUnit::Milliseconds, tz_r))
-        | (Datetime(TimeUnit::Milliseconds, tz_l), Datetime(TimeUnit::Nanoseconds, tz_r)) => {
-            match (tz_l.as_deref(), tz_r.as_deref()) {
-                (Some(""), None) | (None, Some("")) => Some(Datetime(TimeUnit::Milliseconds, None)),
-                _ => None,
-            }
-        }
-
         _ => None,
     }
 }
 
+/// This takes ownership of the DataFrame so that drop is called earlier.
+/// Does not check if schema is correct
+pub fn accumulate_dataframes_vertical_unchecked<I>(dfs: I) -> Result<DataFrame>
+where
+    I: IntoIterator<Item = DataFrame>,
+{
+    let mut iter = dfs.into_iter();
+    let mut acc_df = iter.next().unwrap();
+    for df in iter {
+        acc_df.vstack_mut_unchecked(&df);
+    }
+    Ok(acc_df)
+}
+
 /// This takes ownership of the DataFrame so that drop is called earlier.
 pub fn accumulate_dataframes_vertical<I>(dfs: I) -> Result<DataFrame>
 where
