@@ -323,7 +323,7 @@ pub type IdBuildHasher = BuildHasherDefault<IdHasher>;
 /// accidental quadratic behavior. So do not use an Identity function!
 pub(crate) struct IdxHash {
     // idx in row of Series, DataFrame
-    pub(crate) idx: u32,
+    pub(crate) idx: IdxSize,
     // precomputed hash of T
     hash: u64,
 }
@@ -336,7 +336,7 @@ impl Hash for IdxHash {
 
 impl IdxHash {
     #[inline]
-    pub(crate) fn new(idx: u32, hash: u64) -> Self {
+    pub(crate) fn new(idx: IdxSize, hash: u64) -> Self {
         IdxHash { idx, hash }
     }
 }
@@ -383,7 +383,7 @@ pub(crate) fn this_partition(h: u64, thread_no: u64, n_partitions: u64) -> bool
 
 pub(crate) fn prepare_hashed_relation_threaded<T, I>(
     iters: Vec<I>,
-) -> Vec<HashMap<T, (bool, Vec<u32>), RandomState>>
+) -> Vec<HashMap<T, (bool, Vec<IdxSize>), RandomState>>
 where
     I: Iterator<Item = T> + Send + TrustedLen,
     T: Send + Hash + Eq + Sync + Copy,
@@ -401,7 +401,7 @@ where
             let build_hasher = build_hasher.clone();
             let hashes_and_keys = &hashes_and_keys;
             let partition_no = partition_no as u64;
-            let mut hash_tbl: HashMap<T, (bool, Vec<u32>), RandomState> =
+            let mut hash_tbl: HashMap<T, (bool, Vec<IdxSize>), RandomState> =
                 HashMap::with_hasher(build_hasher);
 
             let n_threads = n_partitions as u64;
@@ -412,7 +412,7 @@ where
                     .iter()
                     .enumerate()
                     .for_each(|(idx, (h, k))| {
-                        let idx = idx as u32;
+                        let idx = idx as IdxSize;
                         // partition hashes by thread no.
                         // So only a part of the hashes go to this hashmap
                         if this_partition(*h, partition_no, n_threads) {
@@ -434,7 +434,7 @@ where
                         }
                     });
 
-                offset += len as u32;
+                offset += len as IdxSize;
             }
             hash_tbl
         })
