@@ -4,6 +4,8 @@ use crate::csv_core::utils::*;
 use crate::csv_core::{buffer::*, parser::*};
 use crate::mmap::ReaderBytes;
 use crate::predicates::PhysicalIoExpr;
+use crate::utils::update_row_counts;
+use crate::RowCount;
 use polars_arrow::array::*;
 use polars_core::utils::accumulate_dataframes_vertical;
 use polars_core::{prelude::*, POOL};
@@ -76,6 +78,7 @@ pub(crate) struct CoreReader<'a> {
     predicate: Option<Arc<dyn PhysicalIoExpr>>,
     aggregate: Option<&'a [ScanAggregation]>,
     to_cast: &'a [&'a Field],
+    row_count: Option<RowCount>,
 }
 
 impl<'a> fmt::Debug for CoreReader<'a> {
@@ -163,6 +166,7 @@ impl<'a> CoreReader<'a> {
         aggregate: Option<&'a [ScanAggregation]>,
         to_cast: &'a [&'a Field],
         skip_rows_after_header: usize,
+        row_count: Option<RowCount>,
     ) -> Result<CoreReader<'a>> {
         #[cfg(any(feature = "decompress", feature = "decompress-fast"))]
         let mut reader_bytes = reader_bytes;
@@ -227,7 +231,8 @@ impl<'a> CoreReader<'a> {
             schema = Cow::Owned(s);
         }
 
-        let null_values = null_values.map(|nv| nv.process(&schema)).transpose()?;
+        // create a null value for every column
+        let mut null_values = null_values.map(|nv| nv.process(&schema)).transpose()?;
 
         if let Some(cols) = columns {
             let mut prj = Vec::with_capacity(cols.len());
@@ -235,6 +240,14 @@ impl<'a> CoreReader<'a> {
                 let i = schema.index_of(&col)?;
                 prj.push(i);
             }
+
+            // update null values with projection
+            null_values = null_values.map(|mut nv| {
+                prj.iter()
+                    .map(|i| std::mem::take(&mut nv[*i]))
+                    .collect::<Vec<_>>()
+            });
+
             projection = Some(prj);
         }
 
@@ -259,12 +272,18 @@ impl<'a> CoreReader<'a> {
             predicate,
             aggregate,
             to_cast,
+            row_count,
         })
     }
 
     fn find_starting_point<'b>(&self, mut bytes: &'b [u8]) -> Result<&'b [u8]> {
         // Skip all leading white space and the occasional utf8-bom
-        bytes = skip_line_ending(skip_whitespace(skip_bom(bytes)).0).0;
+        bytes = skip_whitespace(skip_bom(bytes));
+        // \n\n can be a empty string row of a single column
+        // in other cases we skip it.
+        if self.schema.fields().len() > 1 {
+            bytes = skip_line_ending(bytes)
+        }
 
         // If there is a header we skip it.
         if self.has_header {
@@ -441,7 +460,7 @@ impl<'a> CoreReader<'a> {
                         let projection = &projection;
 
                         let mut read = bytes_offset_thread;
-                        let mut df: Option<DataFrame> = None;
+                        let mut dfs = Vec::with_capacity(256);
 
                         let mut last_read = usize::MAX;
                         loop {
@@ -473,6 +492,7 @@ impl<'a> CoreReader<'a> {
                                 &mut buffers,
                                 ignore_parser_errors,
                                 chunk_size,
+                                self.schema.len(),
                             )?;
 
                             let mut local_df = DataFrame::new_no_checks(
@@ -481,6 +501,11 @@ impl<'a> CoreReader<'a> {
                                     .map(|buf| buf.into_series())
                                     .collect::<Result<_>>()?,
                             );
+                            let current_row_count = local_df.height() as u32;
+                            if let Some(rc) = &self.row_count {
+                                local_df.with_row_count_mut(&rc.name, Some(rc.offset));
+                            };
+
                             if let Some(predicate) = predicate {
                                 let s = predicate.evaluate(&local_df)?;
                                 let mask =
@@ -514,23 +539,18 @@ impl<'a> CoreReader<'a> {
                                     }
                                 }
                             }
-                            match &mut df {
-                                None => df = Some(local_df),
-                                Some(df) => {
-                                    df.vstack_mut(&local_df).unwrap();
-                                }
-                            }
+                            cast_columns(&mut local_df, self.to_cast, false)?;
+                            dfs.push((local_df, current_row_count));
                         }
-
-                        df.map(|mut df| {
-                            cast_columns(&mut df, self.to_cast, false)?;
-                            Ok(df)
-                        })
-                        .transpose()
+                        Ok(dfs)
                     })
                     .collect::<Result<Vec<_>>>()
             })?;
-            accumulate_dataframes_vertical(dfs.into_iter().flatten())
+            let mut dfs = dfs.into_iter().flatten().collect::<Vec<_>>();
+            if self.row_count.is_some() {
+                update_row_counts(&mut dfs)
+            }
+            accumulate_dataframes_vertical(dfs.into_iter().map(|t| t.0))
         } else {
             // let exponential growth solve the needed size. This leads to less memory overhead
             // in the later rechunk. Because we have large chunks they are easier reused for the
@@ -550,7 +570,7 @@ impl<'a> CoreReader<'a> {
                 .map(|_| RunningSize::new(init_str_bytes))
                 .collect();
 
-            let dfs = pool.install(|| {
+            let mut dfs = pool.install(|| {
                 file_chunks
                     .into_par_iter()
                     .map(|(bytes_offset_thread, stop_at_nbytes)| {
@@ -591,6 +611,7 @@ impl<'a> CoreReader<'a> {
                                 // chunk size doesn't really matter anymore,
                                 // less calls if we increase the size
                                 usize::MAX,
+                                self.schema.len(),
                             )?;
                         }
 
@@ -602,11 +623,18 @@ impl<'a> CoreReader<'a> {
                         );
 
                         cast_columns(&mut df, self.to_cast, false)?;
-                        Ok(df)
+                        if let Some(rc) = &self.row_count {
+                            df.with_row_count_mut(&rc.name, Some(rc.offset));
+                        }
+                        let n_read = df.height() as u32;
+                        Ok((df, n_read))
                     })
                     .collect::<Result<Vec<_>>>()
             })?;
-            accumulate_dataframes_vertical(dfs.into_iter())
+            if self.row_count.is_some() {
+                update_row_counts(&mut dfs)
+            }
+            accumulate_dataframes_vertical(dfs.into_iter().map(|t| t.0))
         }
     }
 
