@@ -98,7 +98,8 @@ where
         }
     }
 
-    fn finish(mut self, df: &DataFrame) -> Result<()> {
+    fn finish(mut self, df: &mut DataFrame) -> Result<()> {
+        df.rechunk();
         let batches = df.iter_chunks().map(Ok);
         let names = df.get_column_names_owned();
 
