@@ -72,6 +72,22 @@ impl Debug for dyn SeriesBinaryUdf {
     }
 }
 
+pub trait RenameAliasFn: Send + Sync {
+    fn call(&self, name: &str) -> String;
+}
+
+impl<F: Fn(&str) -> String + Send + Sync> RenameAliasFn for F {
+    fn call(&self, name: &str) -> String {
+        self(name)
+    }
+}
+
+impl Debug for dyn RenameAliasFn {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        write!(f, "RenameAliasFn")
+    }
+}
+
 #[derive(Clone)]
 /// Wrapper type that indicates that the inner type is not equal to anything
 pub struct NoEq<T>(T);
@@ -327,9 +343,8 @@ pub enum Expr {
     Exclude(Box<Expr>, Vec<Excluded>),
     /// Set root name as Alias
     KeepName(Box<Expr>),
-    SufPreFix {
-        is_suffix: bool,
-        value: String,
+    RenameAlias {
+        function: NoEq<Arc<dyn RenameAliasFn>>,
         expr: Box<Expr>,
     },
     /// Special case that does not need columns
@@ -724,23 +739,22 @@ impl Expr {
 
     /// Get unique values of this expression.
     pub fn unique(self) -> Self {
-        assert!(
-            !has_expr(&self, |e| matches!(e, Expr::Wildcard)),
-            "wildcard not supperted in unique expr"
-        );
         self.apply(|s: Series| s.unique(), GetOutput::same_type())
             .with_fmt("unique")
     }
 
+    /// Get unique values of this expression, while maintaining order.
+    /// This requires more work than [`Expr::unique`].
+    pub fn unique_stable(self) -> Self {
+        self.apply(|s: Series| s.unique_stable(), GetOutput::same_type())
+            .with_fmt("unique_stable")
+    }
+
     /// Get the first index of unique values of this expression.
     pub fn arg_unique(self) -> Self {
-        assert!(
-            !has_expr(&self, |e| matches!(e, Expr::Wildcard)),
-            "wildcard not supported in unique expr"
-        );
         self.apply(
             |s: Series| s.arg_unique().map(|ca| ca.into_series()),
-            GetOutput::from_type(DataType::UInt32),
+            GetOutput::from_type(IDX_DTYPE),
         )
         .with_fmt("arg_unique")
     }
@@ -756,7 +770,7 @@ impl Expr {
 
         self.function_with_options(
             move |s: Series| Ok(Series::new(s.name(), &[s.arg_min().map(|idx| idx as u32)])),
-            GetOutput::from_type(DataType::UInt32),
+            GetOutput::from_type(IDX_DTYPE),
             options,
         )
     }
@@ -772,7 +786,7 @@ impl Expr {
 
         self.function_with_options(
             move |s: Series| Ok(Series::new(s.name(), &[s.arg_max().map(|idx| idx as u32)])),
-            GetOutput::from_type(DataType::UInt32),
+            GetOutput::from_type(IDX_DTYPE),
             options,
         )
     }
@@ -792,7 +806,7 @@ impl Expr {
 
         self.function_with_options(
             move |s: Series| Ok(s.argsort(reverse).into_series()),
-            GetOutput::from_type(DataType::UInt32),
+            GetOutput::from_type(IDX_DTYPE),
             options,
         )
     }
@@ -1379,6 +1393,15 @@ impl Expr {
     #[cfg_attr(docsrs, doc(cfg(feature = "is_in")))]
     pub fn is_in(self, other: Expr) -> Self {
         let has_literal = has_root_literal_expr(&other);
+        if has_literal {
+            if let Expr::Literal(LiteralValue::Series(s)) = &other {
+                // nothing is in an empty list return all False
+                if s.is_empty() {
+                    return Expr::Literal(LiteralValue::Boolean(false));
+                }
+            }
+        }
+
         let f = |s: &mut [Series]| {
             let left = &s[0];
             let other = &s[1];
@@ -1397,88 +1420,6 @@ impl Expr {
         .with_fmt("is_in")
     }
 
-    /// Get the year of a Date/Datetime
-    #[cfg(feature = "temporal")]
-    pub fn year(self) -> Expr {
-        let function = move |s: Series| s.year().map(|ca| ca.into_series());
-        self.map(function, GetOutput::from_type(DataType::UInt32))
-            .with_fmt("year")
-    }
-
-    /// Get the month of a Date/Datetime
-    #[cfg(feature = "temporal")]
-    pub fn month(self) -> Expr {
-        let function = move |s: Series| s.month().map(|ca| ca.into_series());
-        self.map(function, GetOutput::from_type(DataType::UInt32))
-            .with_fmt("month")
-    }
-    /// Extract the week from the underlying Date representation.
-    /// Can be performed on Date and Datetime
-
-    /// Returns the ISO week number starting from 1.
-    /// The return value ranges from 1 to 53. (The last week of year differs by years.)
-    #[cfg(feature = "temporal")]
-    pub fn week(self) -> Expr {
-        let function = move |s: Series| s.week().map(|ca| ca.into_series());
-        self.map(function, GetOutput::from_type(DataType::UInt32))
-            .with_fmt("week")
-    }
-
-    /// Extract the week day from the underlying Date representation.
-    /// Can be performed on Date and Datetime.
-
-    /// Returns the weekday number where monday = 0 and sunday = 6
-    #[cfg(feature = "temporal")]
-    pub fn weekday(self) -> Expr {
-        let function = move |s: Series| s.weekday().map(|ca| ca.into_series());
-        self.map(function, GetOutput::from_type(DataType::UInt32))
-            .with_fmt("weekday")
-    }
-
-    /// Get the month of a Date/Datetime
-    #[cfg(feature = "temporal")]
-    pub fn day(self) -> Expr {
-        let function = move |s: Series| s.day().map(|ca| ca.into_series());
-        self.map(function, GetOutput::from_type(DataType::UInt32))
-            .with_fmt("day")
-    }
-    /// Get the ordinal_day of a Date/Datetime
-    #[cfg(feature = "temporal")]
-    pub fn ordinal_day(self) -> Expr {
-        let function = move |s: Series| s.ordinal_day().map(|ca| ca.into_series());
-        self.map(function, GetOutput::from_type(DataType::UInt32))
-            .with_fmt("ordinal_day")
-    }
-    /// Get the hour of a Datetime/Time64
-    #[cfg(feature = "temporal")]
-    pub fn hour(self) -> Expr {
-        let function = move |s: Series| s.hour().map(|ca| ca.into_series());
-        self.map(function, GetOutput::from_type(DataType::UInt32))
-            .with_fmt("hour")
-    }
-    /// Get the minute of a Datetime/Time64
-    #[cfg(feature = "temporal")]
-    pub fn minute(self) -> Expr {
-        let function = move |s: Series| s.minute().map(|ca| ca.into_series());
-        self.map(function, GetOutput::from_type(DataType::UInt32))
-            .with_fmt("minute")
-    }
-
-    /// Get the second of a Datetime/Time64
-    #[cfg(feature = "temporal")]
-    pub fn second(self) -> Expr {
-        let function = move |s: Series| s.second().map(|ca| ca.into_series());
-        self.map(function, GetOutput::from_type(DataType::UInt32))
-            .with_fmt("second")
-    }
-    /// Get the nanosecond of a Time64
-    #[cfg(feature = "temporal")]
-    pub fn nanosecond(self) -> Expr {
-        let function = move |s: Series| s.nanosecond().map(|ca| ca.into_series());
-        self.map(function, GetOutput::from_type(DataType::UInt32))
-            .with_fmt("nanosecond")
-    }
-
     /// Sort this column by the ordering of another column.
     /// Can also be used in a groupby context to sort the groups.
     pub fn sort_by<E: AsRef<[Expr]>, R: AsRef<[bool]>>(self, by: E, reverse: R) -> Expr {
@@ -1497,8 +1438,8 @@ impl Expr {
         let function = |s: &mut [Series]| {
             let by = &s[1];
             let s = &s[0];
-            let by = by.cast(&DataType::UInt32)?;
-            Ok(s.repeat_by(by.u32()?).into_series())
+            let by = by.cast(&IDX_DTYPE)?;
+            Ok(s.repeat_by(by.idx()?).into_series())
         };
 
         self.map_many(
@@ -1559,22 +1500,28 @@ impl Expr {
         Expr::KeepName(Box::new(self))
     }
 
+    /// Define an alias by mapping a function over the original root column name.
+    pub fn map_alias<F>(self, function: F) -> Expr
+    where
+        F: Fn(&str) -> String + 'static + Send + Sync,
+    {
+        let function = NoEq::new(Arc::new(function) as Arc<dyn RenameAliasFn>);
+        Expr::RenameAlias {
+            expr: Box::new(self),
+            function,
+        }
+    }
+
     /// Add a suffix to the root column name.
     pub fn suffix(self, suffix: &str) -> Expr {
-        Expr::SufPreFix {
-            is_suffix: true,
-            value: suffix.to_string(),
-            expr: Box::new(self),
-        }
+        let suffix = suffix.to_string();
+        self.map_alias(move |name| format!("{}{}", name, suffix))
     }
 
     /// Add a prefix to the root column name.
     pub fn prefix(self, prefix: &str) -> Expr {
-        Expr::SufPreFix {
-            is_suffix: false,
-            value: prefix.to_string(),
-            expr: Box::new(self),
-        }
+        let prefix = prefix.to_string();
+        self.map_alias(move |name| format!("{}{}", prefix, name))
     }
 
     /// Exclude a column from a wildcard/regex selection.
@@ -1807,7 +1754,7 @@ impl Expr {
             move |s| Ok(s.rank(options)),
             GetOutput::map_field(move |fld| match options.method {
                 RankMethod::Average => Field::new(fld.name(), DataType::Float32),
-                _ => Field::new(fld.name(), DataType::UInt32),
+                _ => Field::new(fld.name(), IDX_DTYPE),
             }),
         )
         .with_fmt("rank")
@@ -1971,7 +1918,7 @@ impl Expr {
                     Ok(ca.into_series())
                 }
             },
-            GetOutput::from_type(DataType::UInt32),
+            GetOutput::from_type(IDX_DTYPE),
         )
         .with_fmt("cumcount")
     }
@@ -1982,6 +1929,15 @@ impl Expr {
             .with_fmt("shuffle")
     }
 
+    #[cfg(feature = "random")]
+    pub fn sample_frac(self, frac: f64, with_replacement: bool, seed: u64) -> Self {
+        self.apply(
+            move |s| s.sample_frac(frac, with_replacement, seed),
+            GetOutput::same_type(),
+        )
+        .with_fmt("shuffle")
+    }
+
     #[cfg(feature = "ewma")]
     pub fn ewm_mean(self, options: EWMOptions) -> Self {
         use DataType::*;
