@@ -42,6 +42,7 @@ use crate::prelude::{
 use crate::logical_plan::FETCH_ROWS;
 use crate::utils::{combine_predicates_expr, expr_to_root_column_names};
 use polars_arrow::prelude::QuantileInterpolOptions;
+use polars_io::RowCount;
 
 #[derive(Clone, Debug)]
 pub struct JoinOptions {
@@ -280,12 +281,6 @@ impl LazyFrame {
         self.select_local(vec![col("*").reverse()])
     }
 
-    /// Rename a column in the DataFrame
-    #[deprecated(note = "use rename")]
-    pub fn with_column_renamed(self, existing_name: &str, new_name: &str) -> Self {
-        self.rename([existing_name], [new_name])
-    }
-
     /// Rename columns in the DataFrame.
     pub fn rename<I, J, T, S>(self, existing: I, new: J) -> Self
     where
@@ -421,14 +416,25 @@ impl LazyFrame {
         let logical_plan = self.get_plan_builder().build();
 
         // gradually fill the rules passed to the optimizer
+        let opt = StackOptimizer {};
         let mut rules: Vec<Box<dyn OptimizationRule>> = Vec::with_capacity(8);
 
+        if simplify_expr {
+            rules.push(Box::new(SimplifyExprRule {}));
+            rules.push(Box::new(SimplifyBooleanRule {}));
+        }
+
         // during debug we check if the optimizations have not modified the final schema
         #[cfg(debug_assertions)]
         let prev_schema = logical_plan.schema().clone();
 
         let mut lp_top = to_alp(logical_plan, expr_arena, lp_arena);
 
+        // simplify expression is valuable for projection and predicate pushdown optimizers, so we
+        // run that first
+        // this optimization will run twice because optimizer may create dumb expressions
+        lp_top = opt.optimize_loop(&mut rules, expr_arena, lp_arena, lp_top);
+
         if projection_pushdown {
             let projection_pushdown_opt = ProjectionPushDown {};
             let alp = lp_arena.take(lp_top);
@@ -461,10 +467,6 @@ impl LazyFrame {
             rules.push(Box::new(TypeCoercionRule {}))
         }
 
-        if simplify_expr {
-            rules.push(Box::new(SimplifyExprRule {}));
-            rules.push(Box::new(SimplifyBooleanRule {}));
-        }
         if aggregate_pushdown {
             rules.push(Box::new(AggregatePushdown::new()))
         }
@@ -483,7 +485,6 @@ impl LazyFrame {
         rules.push(Box::new(FastProjection {}));
         rules.push(Box::new(ReplaceDropNulls {}));
 
-        let opt = StackOptimizer {};
         lp_top = opt.optimize_loop(&mut rules, expr_arena, lp_arena, lp_top);
 
         // during debug we check if the optimizations have not modified the final schema
@@ -866,15 +867,6 @@ impl LazyFrame {
         Self::from_logical_plan(lp, opt_state)
     }
 
-    /// Drop duplicate rows. [See eager](polars_core::prelude::DataFrame::drop_duplicates).
-    #[deprecated(note = "use distinct")]
-    pub fn drop_duplicates(self, maintain_order: bool, subset: Option<Vec<String>>) -> LazyFrame {
-        match maintain_order {
-            true => self.distinct_stable(subset, DistinctKeepStrategy::First),
-            false => self.distinct(subset, DistinctKeepStrategy::First),
-        }
-    }
-
     /// Keep unique rows and maintain order
     pub fn distinct_stable(
         self,
@@ -938,7 +930,7 @@ impl LazyFrame {
         self.slice(-1, 1)
     }
 
-    /// Get the n last rows
+    /// Get the last `n` rows
     pub fn tail(self, n: u32) -> LazyFrame {
         let neg_tail = -(n as i64);
         self.slice(neg_tail, n)
@@ -991,21 +983,59 @@ impl LazyFrame {
     }
 
     /// Add a new column at index 0 that counts the rows.
-    pub fn with_row_count(self, name: &str) -> LazyFrame {
-        let schema = self.schema();
+    ///
+    /// # Warning
+    /// This can have a negative effect on query performance.
+    /// This may for instance block predicate pushdown optimization.
+    pub fn with_row_count(mut self, name: &str, offset: Option<u32>) -> LazyFrame {
+        match &mut self.logical_plan {
+            // Do the row count at scan
+            #[cfg(feature = "csv-file")]
+            LogicalPlan::CsvScan { options, .. } => {
+                options.row_count = Some(RowCount {
+                    name: name.to_string(),
+                    offset: offset.unwrap_or(0),
+                });
+                self
+            }
+            #[cfg(feature = "ipc")]
+            LogicalPlan::IpcScan { options, .. } => {
+                options.row_count = Some(RowCount {
+                    name: name.to_string(),
+                    offset: offset.unwrap_or(0),
+                });
+                self
+            }
+            #[cfg(feature = "parquet")]
+            LogicalPlan::ParquetScan { options, .. } => {
+                options.row_count = Some(RowCount {
+                    name: name.to_string(),
+                    offset: offset.unwrap_or(0),
+                });
+                self
+            }
+            _ => {
+                let schema = self.schema();
 
-        let mut fields = schema.fields().clone();
-        fields.insert(0, Field::new(name, DataType::UInt32));
-        let new_schema = Schema::new(fields);
+                let mut fields = schema.fields().clone();
+                fields.insert(0, Field::new(name, DataType::UInt32));
+                let new_schema = Schema::new(fields);
 
-        let name = name.to_owned();
+                let name = name.to_owned();
 
-        self.map(
-            move |df: DataFrame| df.with_row_count(&name),
-            Some(AllowedOptimizations::default()),
-            Some(new_schema),
-            Some("WITH ROW COUNT"),
-        )
+                let opt = AllowedOptimizations {
+                    slice_pushdown: false,
+                    predicate_pushdown: false,
+                    ..Default::default()
+                };
+                self.map(
+                    move |df: DataFrame| df.with_row_count(&name, offset),
+                    Some(opt),
+                    Some(new_schema),
+                    Some("WITH ROW COUNT"),
+                )
+            }
+        }
     }
 }
 
