@@ -1,5 +1,5 @@
 #[cfg(feature = "ipc")]
-use crate::logical_plan::LpScanOptions;
+use crate::logical_plan::IpcScanOptions;
 #[cfg(feature = "parquet")]
 use crate::logical_plan::ParquetOptions;
 use crate::logical_plan::{det_melt_schema, Context, CsvParserOptions};
@@ -48,7 +48,7 @@ pub enum ALogicalPlan {
         schema: SchemaRef,
         // schema of the projected file
         output_schema: Option<SchemaRef>,
-        options: LpScanOptions,
+        options: IpcScanOptions,
         predicate: Option<Node>,
         aggregate: Vec<Node>,
     },
@@ -533,6 +533,19 @@ impl<'a> ALogicalPlanBuilder<'a> {
         }
     }
 
+    pub(crate) fn from_lp(
+        lp: ALogicalPlan,
+        expr_arena: &'a mut Arena<AExpr>,
+        lp_arena: &'a mut Arena<ALogicalPlan>,
+    ) -> Self {
+        let root = lp_arena.add(lp);
+        ALogicalPlanBuilder {
+            root,
+            expr_arena,
+            lp_arena,
+        }
+    }
+
     pub fn melt(self, id_vars: Arc<Vec<String>>, value_vars: Arc<Vec<String>>) -> Self {
         let schema = det_melt_schema(&value_vars, self.schema());
 
