@@ -146,6 +146,9 @@ impl PyExpr {
     pub fn unique(&self) -> PyExpr {
         self.clone().inner.unique().into()
     }
+    pub fn unique_stable(&self) -> PyExpr {
+        self.clone().inner.unique_stable().into()
+    }
     pub fn first(&self) -> PyExpr {
         self.clone().inner.first().into()
     }
@@ -594,34 +597,34 @@ impl PyExpr {
     }
 
     pub fn year(&self) -> PyExpr {
-        self.clone().inner.year().into()
+        self.clone().inner.dt().year().into()
     }
     pub fn month(&self) -> PyExpr {
-        self.clone().inner.month().into()
+        self.clone().inner.dt().month().into()
     }
     pub fn week(&self) -> PyExpr {
-        self.clone().inner.week().into()
+        self.clone().inner.dt().week().into()
     }
     pub fn weekday(&self) -> PyExpr {
-        self.clone().inner.weekday().into()
+        self.clone().inner.dt().weekday().into()
     }
     pub fn day(&self) -> PyExpr {
-        self.clone().inner.day().into()
+        self.clone().inner.dt().day().into()
     }
     pub fn ordinal_day(&self) -> PyExpr {
-        self.clone().inner.ordinal_day().into()
+        self.clone().inner.dt().ordinal_day().into()
     }
     pub fn hour(&self) -> PyExpr {
-        self.clone().inner.hour().into()
+        self.clone().inner.dt().hour().into()
     }
     pub fn minute(&self) -> PyExpr {
-        self.clone().inner.minute().into()
+        self.clone().inner.dt().minute().into()
     }
     pub fn second(&self) -> PyExpr {
-        self.clone().inner.second().into()
+        self.clone().inner.dt().second().into()
     }
     pub fn nanosecond(&self) -> PyExpr {
-        self.clone().inner.nanosecond().into()
+        self.clone().inner.dt().nanosecond().into()
     }
     pub fn duration_days(&self) -> PyExpr {
         self.inner
@@ -688,6 +691,14 @@ impl PyExpr {
             .into()
     }
 
+    pub fn dt_with_time_unit(&self, tu: Wrap<TimeUnit>) -> PyExpr {
+        self.inner.clone().dt().with_time_unit(tu.0).into()
+    }
+
+    pub fn dt_cast_time_unit(&self, tu: Wrap<TimeUnit>) -> PyExpr {
+        self.inner.clone().dt().cast_time_unit(tu.0).into()
+    }
+
     pub fn rolling_apply(
         &self,
         py: Python,
@@ -864,6 +875,17 @@ impl PyExpr {
     pub fn suffix(&self, suffix: &str) -> PyExpr {
         self.inner.clone().suffix(suffix).into()
     }
+    pub fn map_alias(&self, lambda: PyObject) -> PyExpr {
+        self.inner
+            .clone()
+            .map_alias(move |name| {
+                let gil = Python::acquire_gil();
+                let py = gil.python();
+                let out = lambda.call1(py, (name,)).unwrap();
+                out.to_string()
+            })
+            .into()
+    }
     pub fn exclude(&self, columns: Vec<String>) -> PyExpr {
         self.inner.clone().exclude(&columns).into()
     }
@@ -1160,6 +1182,13 @@ impl PyExpr {
         self.inner.clone().shuffle(seed).into()
     }
 
+    pub fn sample_frac(&self, frac: f64, with_replacement: bool, seed: u64) -> Self {
+        self.inner
+            .clone()
+            .sample_frac(frac, with_replacement, seed)
+            .into()
+    }
+
     pub fn ewm_mean(&self, alpha: f64, adjust: bool, min_periods: usize) -> Self {
         let options = EWMOptions {
             alpha,
