@@ -50,6 +50,21 @@ fn col(name: &str) -> dsl::PyExpr {
     dsl::col(name)
 }
 
+#[pyfunction]
+fn count() -> dsl::PyExpr {
+    dsl::count()
+}
+
+#[pyfunction]
+fn first() -> dsl::PyExpr {
+    dsl::first()
+}
+
+#[pyfunction]
+fn last() -> dsl::PyExpr {
+    dsl::last()
+}
+
 #[pyfunction]
 fn cols(names: Vec<String>) -> dsl::PyExpr {
     dsl::cols(names)
@@ -344,6 +359,9 @@ fn polars(_py: Python, m: &PyModule) -> PyResult<()> {
     m.add_class::<PyLazyGroupBy>().unwrap();
     m.add_class::<dsl::PyExpr>().unwrap();
     m.add_wrapped(wrap_pyfunction!(col)).unwrap();
+    m.add_wrapped(wrap_pyfunction!(count)).unwrap();
+    m.add_wrapped(wrap_pyfunction!(first)).unwrap();
+    m.add_wrapped(wrap_pyfunction!(last)).unwrap();
     m.add_wrapped(wrap_pyfunction!(cols)).unwrap();
     m.add_wrapped(wrap_pyfunction!(dtype_cols)).unwrap();
     m.add_wrapped(wrap_pyfunction!(lit)).unwrap();
