@@ -87,3 +87,27 @@ def test_count_expr() -> None:
     out = df.groupby("b", maintain_order=True).agg(pl.count())
     assert out["b"].to_list() == ["a", "b"]
     assert out["count"].to_list() == [4, 1]
+
+
+def test_sample() -> None:
+    a = pl.Series("a", range(0, 20))
+    out = pl.select(pl.lit(a).sample(0.5, False, 1)).to_series()
+    assert out.shape == (10,)
+    assert out.to_list() != out.sort().to_list()
+    assert out.unique().shape == (10,)
+
+
+def test_map_alias() -> None:
+    out = pl.DataFrame({"foo": [1, 2, 3]}).select(
+        (pl.col("foo") * 2).map_alias(lambda name: f"{name}{name}")
+    )
+
+    expected = pl.DataFrame({"foofoo": [2, 4, 6]})
+    assert out.frame_equal(expected)
+
+
+def test_unique_stable() -> None:
+    a = pl.Series("a", [1, 1, 1, 1, 2, 2, 2, 3, 3])
+    expected = pl.Series("a", [1, 2, 3])
+
+    verify_series_and_expr_api(a, expected, "unique", True)
