@@ -81,6 +81,26 @@ def test_compressed_to_ipc() -> None:
         assert df_read.frame_equal(df)
 
 
+def test_read_avro() -> None:
+    small_avro = Path(__file__).parent / "files" / "small.avro"
+    expected = pl.DataFrame({"i64": [1, 2], "f64": [0.1, 0.2], "utf8": ["a", "b"]})
+    df_read = pl.read_avro(str(small_avro))
+    assert df_read.frame_equal(expected)
+
+
+def test_compressed_to_avro() -> None:
+    df = pl.DataFrame({"i64": [1, 2], "f64": [0.1, 0.2], "utf8": ["a", "b"]})
+    compressions = ["uncompressed", "snappy", "deflate"]
+
+    for compression in compressions:
+        f = io.BytesIO()
+        df.to_avro(f, compression)  # type: ignore
+        f.seek(0)
+
+        df_read = pl.read_avro(f)
+        assert df_read.frame_equal(df)
+
+
 def test_read_web_file() -> None:
     url = "https://raw.githubusercontent.com/pola-rs/polars/master/examples/aggregate_multiple_files_in_chunks/datasets/foods1.csv"
     df = pl.read_csv(url)
@@ -591,3 +611,34 @@ def test_from_different_chunks() -> None:
     out = df.to_pandas()
     assert list(out.columns) == ["a", "b"]
     assert out.shape == (5, 2)
+
+
+def test_row_count(foods_csv: str, foods_ipc: str, foods_parquet: str) -> None:
+    for read, scan in [
+        (partial(pl.read_csv, foods_csv), partial(pl.scan_csv, foods_csv)),
+        (
+            partial(pl.read_ipc, foods_ipc, use_pyarrow=False),
+            partial(pl.scan_ipc, foods_ipc),
+        ),
+        (
+            partial(pl.read_parquet, foods_parquet),
+            partial(pl.scan_parquet, foods_parquet),
+        ),
+    ]:
+
+        df = read(row_count_name="row_count")
+        assert df["row_count"].to_list() == list(range(27))
+        df = (
+            scan(row_count_name="row_count")
+            .filter(pl.col("category") == pl.lit("vegetables"))
+            .collect()
+        )
+        assert df["row_count"].to_list() == [0, 6, 11, 13, 14, 20, 25]
+        # make sure that row count is correct even though predicate is pushed down
+        df = (
+            scan()
+            .with_row_count("foo", 10)
+            .filter(pl.col("category") == pl.lit("vegetables"))
+            .collect()
+        )
+        assert df["foo"].to_list() == [10, 16, 21, 23, 24, 30, 35]
